@@ -6,6 +6,9 @@ from chorde.serialize import serialize_read, serialize_write, serialize
 # Overridden by inproc_cache based on LRUCache availability
 CacheMissError = KeyError
 
+class NoServersError(Exception):
+    pass
+
 try:
     from concurrent.futures import TimeoutError, CancelledError
 except ImportError:
@@ -42,7 +45,7 @@ class BaseCacheClient(object):
         will wait for it to finish. If there is not, it will return immediately.
         """
         pass
-    
+
     @abstractmethod
     def put(self, key, value, ttl):
         raise NotImplementedError
@@ -96,25 +99,28 @@ class BaseCacheClient(object):
 
             If promote_callback is given, and the operation results in a promotion
             from a lower level to a higher one, promote_callback will be called
-            with 3 arguments: the key as given, the value being promoted, 
+            with 3 arguments: the key as given, the value being promoted,
             and the remaining TTL.
         """
         if default is NONE:
             raise CacheMissError, key
         else:
             return (default, -1)
-    
+
     def promote(self, key, default = NONE, ttl_skip = None, promote_callback = None):
         """
         Returns: None. If getTtl would find an entry with the given arguments,
             this entry will be promoted. Otherwise, it's a no-op.
         """
         return
-    
+
     def get(self, key, default = NONE, **kw):
         rv, ttl = self.getTtl(key, default, **kw)
-        if ttl < 0 and default is NONE:
-            raise CacheMissError, key
+        if ttl < 0:
+            if default is NONE:
+                raise CacheMissError, key
+            else:
+                return default
         else:
             return rv
 
@@ -173,7 +179,7 @@ class BaseCacheClient(object):
     def purge(self, timeout = 0):
         """
         Params
-            
+
             timeout: if specified, only items that have been stale for
                 this amount of time will be removed. That is, it is added to the
                 initial entry's TTL vale.
@@ -250,7 +256,7 @@ class ReadWriteSyncAdapter(BaseCacheClient):
     @serialize_write
     def promote(self, *p, **kw):
         return self.client.promote(*p, **kw)
-    
+
     @serialize_write
     def clear(self):
         return self.client.clear()
@@ -325,7 +331,7 @@ class SyncAdapter(BaseCacheClient):
     @serialize_write
     def promote(self, *p, **kw):
         return self.client.promote(*p, **kw)
-    
+
     @serialize
     def clear(self):
         return self.client.clear()
@@ -350,8 +356,8 @@ class DecoratedWrapper(BaseCacheClient):
     A namespace wrapper client will decorate keys with a namespace, making it possible
     to share one client among many sub-clients without key collisions.
     """
-    def __init__(self, client, 
-            key_decorator = None, key_undecorator = None, 
+    def __init__(self, client,
+            key_decorator = None, key_undecorator = None,
             value_decorator = None, value_undecorator = None):
         self.client = client
         self.key_decorator = key_decorator
@@ -376,7 +382,7 @@ class DecoratedWrapper(BaseCacheClient):
         if key_decorator:
             key = key_decorator(key)
         return self.client.wait(key, timeout)
-    
+
     def put(self, key, value, ttl, **kw):
         key_decorator = self.key_decorator
         if key_decorator:
@@ -498,7 +504,7 @@ class DecoratedWrapper(BaseCacheClient):
             if key_undecorator is not None and 'promote_callback' in kw:
                 self._wrapPromoteCallback(key_undecorator, kw)
         self.client.promote(key, *p, **kw)
-    
+
     def clear(self):
         return self.client.clear()
 
@@ -519,10 +525,14 @@ class NamespaceWrapper(DecoratedWrapper):
     def __init__(self, namespace, client, revmark_ttl=FOREVER):
         super(NamespaceWrapper, self).__init__(client)
         self.namespace = namespace
-        self.revision = client.get((namespace,'REVMARK'), 0)
         self.key_undecorator = operator.itemgetter(2)
         self.revmark_ttl = revmark_ttl
 
+        try:
+            self.revision = client.get((namespace,'REVMARK'), 0)
+        except NoServersError:
+            self.revision = 0
+
     key_decorator = property(
         operator.attrgetter('_key_decorator'),
         lambda self, value : None)
@@ -586,13 +596,37 @@ class NamespaceMirrorWrapper(NamespaceWrapper):
         return self.reference.revision
 
     @revision.setter
-    def revision(self, value):  # lint:ok
-        pass
+    def revision(self, value):
+        self.reference.revision = value
 
     @property
     def namespace(self):
         return self.reference.namespace
 
     @namespace.setter
-    def namespace(self):  # lint:ok
+    def namespace(self, value):  # lint:ok
         pass
+
+    @property
+    def key_undecorator(self):
+        return self.reference.key_undecorator
+
+    @key_undecorator.setter
+    def key_undecorator(self, value):  # lint:ok
+        pass
+
+    @property
+    def key_decorator(self):
+        return self.reference.key_decorator
+
+    @key_decorator.setter
+    def key_decorator(self, value):  # lint:ok
+        pass
+
+    @property
+    def revmark_ttl(self):
+        return self.reference.revmark_ttl
+
+    @revmark_ttl.setter
+    def revmark_ttl(self, value):
+        self.reference.revmark_ttl = value
